<?php
/**
 * OSB V2-Payment Module version 1.8.0 for Magento 1.4-1.9. Support contact : support@osb.pf.
 *
 * NOTICE OF LICENSE
 *
 * This source file is licensed under the Open Software License version 3.0
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/osl-3.0.php
 *
 * @author    Lyra Network (http://www.lyra-network.com/)
 * @copyright 2014-2017 Lyra Network and contributors
 * @license   https://opensource.org/licenses/osl-3.0.php  Open Software License (OSL 3.0)
 * @category  payment
 * @package   osb
 */

class Lyra_Osb_Model_Payment_Sofort extends Lyra_Osb_Model_Payment_Abstract
{
    protected $_code = 'osb_sofort';
    protected $_formBlockType = 'osb/sofort';

    protected $_canUseInternal = false;

    protected $_currencies = array('EUR', 'CHF', 'GBP', 'PLN');

    protected  function _setExtraFields($order)
    {
        // override with Sofort banking payment card
        $this->_osbRequest->set('payment_cards', 'SOFORT_BANKING');
    }

    /**
     * Assign data to info model instance
     *
     * @param mixed $data
     * @return Mage_Payment_Model_Info
     */
    public function assignData($data)
    {
        $info = $this->getInfoInstance();

        // init all payment data
        $info->setCcType(null)
                ->setCcLast4(null)
                ->setCcNumber(null)
                ->setCcCid(null)
                ->setCcExpMonth(null)
                ->setCcExpYear(null)
                ->setAdditionalData(null);

        return $this;
    }

    public function canUseForCountry($country)
    {
        $availableCountries = Mage::getModel('osb/source_sofort_availableCountries')->getCountryCodes();

        if ($this->getConfigData('allowspecific') == 1) {
            $availableCountries = explode(',', $this->getConfigData('specificcountry'));
        }

        return in_array($country, $availableCountries);
    }
}
